"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const CSSContext_1 = require("./CSSContext");
const isServer_1 = require("./utils/isServer");
function createCSSCollector(renderLoading, renderError, displayName = 'CSSCollector') {
    const ScopedCSSCollector = (props) => {
        return (React.createElement(CSSContext_1.Consumer, null, (context) => (React.createElement(CSSCollectorLifecycle, Object.assign({ context: context, renderError: renderError, renderLoading: renderLoading }, props)))));
    };
    ScopedCSSCollector.displayName = displayName;
    return ScopedCSSCollector;
}
exports.createCSSCollector = createCSSCollector;
exports.CSSCollector = createCSSCollector();
class CSSCollectorLifecycle extends React.Component {
    /**
     * get Fetch State from state array.
     * @param {CSSFetchState[]} states
     * @return {CSSFetchState}
     */
    static getFetchState(states) {
        let isLoading;
        for (const state of states) {
            // if some error state, return Error.
            if (state === CSSContext_1.CSSFetchState.Error) {
                return CSSContext_1.CSSFetchState.Error;
            }
            if (state === CSSContext_1.CSSFetchState.Loading || !state) {
                isLoading = true;
            }
        }
        if (isLoading) {
            return CSSContext_1.CSSFetchState.Loading;
        }
        else {
            return CSSContext_1.CSSFetchState.Success;
        }
    }
    constructor(props) {
        super(props);
        const { context, hrefs, } = props;
        // When this instance created, access context api.
        context.multiUpdate(hrefs);
    }
    render() {
        const { context, hrefs, } = this.props;
        const state = CSSCollectorLifecycle.getFetchState(hrefs.map((href) => {
            return context.cssMap.get(href);
        }));
        // if SSR, it should be render.
        if (state === CSSContext_1.CSSFetchState.Success || isServer_1.isServer()) {
            return React.createElement(React.Fragment, null, this.props.children);
        }
        if (state === CSSContext_1.CSSFetchState.Loading || !state) {
            return this.props.renderLoading ? this.props.renderLoading() : null;
        }
        if (state === CSSContext_1.CSSFetchState.Error) {
            return this.props.renderError ? this.props.renderError() : null;
        }
        return null;
    }
}
//# sourceMappingURL=CSSCollector.js.map