"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const CSSContext_1 = require("./CSSContext");
const appendCSS_1 = require("./utils/appendCSS");
const isServer_1 = require("./utils/isServer");
class CSSProvider extends React.Component {
    /**
     * @constructor
     * @param {Readonly<CSSProviderProps>} props
     */
    constructor(props) {
        super(props);
        /**
         * update CSS-Map in CSSContext.
         * @param {string} href
         */
        this.update = (href) => {
            if (isServer_1.isServer()) {
                // if SSR
                // CSSCollector always pass the CSSLoadingState in SSR phase.
                // Then override the CSS-Map which is defined before server side rendering.
                this.props.cssMap.set(href, CSSContext_1.CSSFetchState.Success);
            }
            else {
                // if CSR
                // CSSCollector state is default Loading. (when css is not append yet.)
                // Append the link element with css.
                // When css file’s have been loaded, CSSCollector state will change to Success.
                // or if error, CSSCollector state will be Error.
                if (this.state.cssMap.get(href) !== CSSContext_1.CSSFetchState.Success) {
                    appendCSS_1.appendCSS(href, () => {
                        this.updateCSSMap(href, CSSContext_1.CSSFetchState.Success);
                    }, () => {
                        this.updateCSSMap(href, CSSContext_1.CSSFetchState.Error);
                    });
                }
            }
        };
        /**
         * multiple update CSS-Map in CSSContext.
         * @param {string[]} hrefs
         */
        this.multiUpdate = (hrefs) => {
            hrefs.forEach((href) => {
                this.update(href);
            });
        };
        this.state = {
            cssMap: props.cssMap,
            multiUpdate: this.multiUpdate,
            update: this.update,
        };
    }
    /**
     * set new CSS-Map state.
     * @param {string} href
     * @param {CSSFetchState} state
     */
    updateCSSMap(href, state) {
        // create new CSS-Map to avoid override refs.
        const cssMap = new Map(this.state.cssMap.entries());
        cssMap.set(href, state);
        this.setState({
            cssMap,
        });
    }
    render() {
        return (React.createElement(CSSContext_1.Provider, { value: this.state }, React.Children.only(this.props.children)));
    }
}
exports.CSSProvider = CSSProvider;
//# sourceMappingURL=CSSProvider.js.map